#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hslogger
version:              1.3.2.0
visibility:           public
id:                   hslogger-1.3.2.0-BIrSd8Hic0SHfRAmfDqIH1
key:                  hslogger-1.3.2.0-BIrSd8Hic0SHfRAmfDqIH1
license:              BSD-3-Clause
copyright:
    Copyright (c) 2004-2018 John Goerzen
    , (c) 2019      Herbert Valerio Riedel

maintainer:           https://github.com/haskell-hvr/hslogger
author:               John Goerzen
homepage:             https://github.com/haskell-hvr/hslogger/wiki
synopsis:             Versatile logging framework
description:
    @hslogger@ is a logging framework for Haskell, roughly similar
    to [Python'\''s logging module](https://docs.python.org/2/library/logging.html).

    @hslogger@ lets each log message have a priority and source be associated
    with it.  The programmer can then define global handlers that route
    or filter messages based on the priority and source.  @hslogger@ also
    has a [Syslog](https://tools.ietf.org/html/rfc5424) handler built in.

category:             Interfaces
abi:                  57fd62fe7b58b73b2e52f6f37d04f4c5
exposed:              True
exposed-modules:
    System.Log System.Log.Formatter System.Log.Handler
    System.Log.Handler.Growl System.Log.Handler.Log4jXML
    System.Log.Handler.Simple System.Log.Handler.Syslog
    System.Log.Logger

hidden-modules:       UTF8
import-dirs:          /usr/lib/ghc-9.6.6/site-local/hslogger-1.3.2.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/hslogger-1.3.2.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/hslogger-1.3.2.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hslogger
hs-libraries:         HShslogger-1.3.2.0-BIrSd8Hic0SHfRAmfDqIH1
depends:
    base-4.18.2.1 bytestring-0.11.5.3 containers-0.6.7 deepseq-1.4.8.1
    network-3.1.4.0-Ds5DY5mKlnsDQk8HC4tJQL
    network-bsd-2.8.1.0-CHMLDNXllaZ5lauUIkGB8E time-1.12.2 unix-2.8.4.0

haddock-interfaces:   /usr/share/doc/haskell-hslogger/html/hslogger.haddock
haddock-html:         /usr/share/doc/haskell-hslogger/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

